<?php
/*
Plugin Name: Block Common Crawl via robots.txt
Plugin URI: https://apasionados.es/#utm_source=wpadmin&utm_medium=plugin&utm_campaign=block-common-crawl-via-robots-txt
Description: Blocks the Common Crawl bot (CCBot) that gathers data that is used to train AI algorithms like ChatGPT through the WordPress virtual robots.txt file
Version: 1.0.0
Author: Apasionados, Apasionados del Marketing
Author URI: https://apasionados.es
Text Domain: block-common-crawl-via-robots-txt

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

add_filter( 'robots_txt', 'apa_block_common_crawl_robots_txt', 20, 2 );
function apa_block_common_crawl_robots_txt( $output, $public ) {
	if ( '1' == $public ) { // Checks whether the site is considered "public".
		$output .= "\n" . "# Block Common Crawl (CCBot)" . "\n" . "# More info: https://commoncrawl.org/big-picture/frequently-asked-questions/" . "\n" . "User-agent: CCBot" . "\n" . "Disallow: /" . "\n";
	}
	return wp_kses($output, 'strip');
}

/**
 * Do some check on plugin activation
  */
function apa_block_common_crawl_robots_txt_f_activation() {
	$plugin_data = get_plugin_data( __FILE__ );
	$plugin_version = $plugin_data['Version'];
	$plugin_name = $plugin_data['Name'];
	$protocol = is_ssl() ? 'https://' : 'http://'; // uses WP function is_ssl()
	$robots   = sanitize_url( $protocol . $_SERVER['SERVER_NAME'] .'/robots.txt' );
    load_plugin_textdomain( 'block-common-crawl-via-robots-txt', false, basename( dirname( __FILE__ ) ) . '/languages' );
	if ( file_exists("{$_SERVER['DOCUMENT_ROOT']}/robots.txt") ) { 
		deactivate_plugins( plugin_basename( __FILE__ ) );
		wp_die( '<h1>' . __('Could not activate plugin: Physical robots.txt file present', 'block-common-crawl-via-robots-txt' ) . '</h1><h2>PLUGIN: <i>' . esc_html($plugin_name) . ' ' . esc_html($plugin_version) . '</i></h2><p><strong>' . __('In order to use this plugin you need to remove the physical robots.txt file from your server. Please delete the robots.txt file via FTP or Server Panel before using this plugin.', 'block-common-crawl-via-robots-txt' ) . '</p><p><blockquote>' . __('This plugin makes changes to the virtual robots.txt file generated automagically by WordPress and doesn\'t work with a physical robots.txt file.', 'block-common-crawl-via-robots-txt' ) . '</blockquote></p><p>' . __('Please note that the robots.txt must be in the top-level directory of your web server. If WordPress is installed in a subdirectory this plugin will not be effective because the robots.txt file generated by WordPress in the subdirectory will be ignored by the bots. Please note that we don\'t check this. You can read more about the robots.txt standard here:', 'block-common-crawl-via-robots-txt' ) .' <a href="http://www.robotstxt.org/robotstxt.html" rel="nofollow noopener noreferrer" target="_blank" rel="noopener">robotstxt.org: How to create a /robots.txt file and Where to put it</a>' . '</p><p>' . __('You can find the robots.txt on the root of your domain:', 'block-common-crawl-via-robots-txt' ) . ' <a href="' . esc_html($robots) . '" target="_blank" rel="nofollow noopener noreferrer">' . esc_html($robots) . '</a>', __('Could not activate plugin: Physical robots.txt file present', 'block-common-crawl-via-robots-txt' ), array( 'back_link' => true ) );
	}
}
register_activation_hook( __FILE__, 'apa_block_common_crawl_robots_txt_f_activation' );

/**
 * Read translations.
 */
function apa_block_common_crawl_robots_txt_f_init() {
	load_plugin_textdomain( 'block-common-crawl-via-robots-txt', false,  dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
}
add_action('plugins_loaded', 'apa_block_common_crawl_robots_txt_f_init');

